@@ -1,19 +1,24 @@
 #!/usr/bin/env python
 import os
 
+is_prod = os.path.exists(os.path.join(os.path.dirname(__file__), 'production.py'))
+
+if is_prod:
+    env = 'prod-env'
+else:
+    env = 'devel-env'
+
 # load virtual environment from devel-env before executing this file
 if os.name == 'nt':
-    activate_this = os.path.join(os.path.dirname(__file__), "..", "devel-env", 'Scripts','activate_this.py')
+    activate_this = os.path.join(os.path.dirname(__file__), "..", env, 'Scripts','activate_this.py')
 else:
-    activate_this = os.path.join(os.path.dirname(__file__), "..", "devel-env", 'bin','activate_this.py')
+    activate_this = os.path.join(os.path.dirname(__file__), "..", env, 'bin','activate_this.py')
 execfile(activate_this, dict(__file__=activate_this))
 
 from django.core.management import execute_manager
 import imp
 
 
-is_prod = os.path.exists(os.path.join(os.path.dirname(__file__), 'production.py'))
-
 try:
     if is_prod:
         imp.find_module('production')
